#!/bin/sh
#
# convert_exports:
#
# usage:  convert_exports [-password <rgy_password>]
#
# set up all views and VOBs on this host for non-ClearCase (NFS) access.
# Useful for conversions from ClearCase V2 to ClearCase V3.  Run this
# script on each host that has exported views/VOBs.
#
# If public VOB tags need modification, then the registry password will be
# required.  You may supply the -password option to this script, or
# type in the password manually for each VOB tag modification that requires it.
#
# There is no need to run this script if you do not export any view/VOB pairs
# (via the exports.mvfs file or the export_mvfs program)
#
PATH=${PATH}:${CLEARCASEHOME:-${ATRIAHOME:-/opt/rational/clearcase}}/bin
export PATH
password=$*
somedone=0
if [ ! -f /etc/exports.mvfs ]; then
	echo "No exported views/VOBs on this host"
	exit 0
fi
for i in `grep '^/view' /etc/exports.mvfs |awk -F/ '{print $3}'|sort -u`; do
	cleartool lsview -long $i >/tmp/$$.tmp
	options=`grep 'export ID' /tmp/$$.tmp`
	if [ ! -z "$options" ]; then
			continue	# the 'for' loop
	fi
	echo Processing view tag '"'$i'"'
	gpath=`grep "Global path" /tmp/$$.tmp |awk '{print $3}'`
	hpath=`grep "server access path" /tmp/$$.tmp |awk '{print $5}'`
	svrhost=`grep "Server host" /tmp/$$.tmp |awk '{print $3}'`
	cleartool mktag -view -tag $i -replace -ncaexported -host $svrhost \
		-hpath $hpath -gpath $gpath $hpath
	somedone=1
done
for i in `grep '^/view' /etc/exports.mvfs | sed -e 's/ .*//' -e 's:/view/[^/]*/:/:'`; do
	cleartool lsvob -long $i >/tmp/$$.tmp
	gpath=`grep "Global path" /tmp/$$.tmp |awk '{print $3}'`
	hpath=`grep "server access path" /tmp/$$.tmp |awk '{print $5}'`
	options=`grep "Mount options" /tmp/$$.tmp |awk '{print $3}'`
	case "$options" in
		*exportid=*)
			continue	# the 'for' loop
			;;
	esac
	echo Processing VOB tag '"'$i'"'
	if [ ! -z "$options" ]; then
		options="-options \"$options\""
	fi
	public=`grep "Access: public" /tmp/$$.tmp`
	if [ ! -z "$public" ]; then
		public="-public"
	fi
	svrhost=`grep "Server host" /tmp/$$.tmp |awk '{print $3}'`
	cleartool mktag -vob -tag $i -replace -ncaexported \
		-host $svrhost -hpath $hpath -gpath $gpath $options $public \
		$password $hpath
	somedone=1
done
case $somedone in
	1)
		echo "Note: you must stop and restart ClearCase for these changes"
		echo "to take effect."
		;;
	0)
		echo "All exported views/VOBs on this host are already set up properly."
		;;
esac
rm -f /tmp/$$.tmp
